@@ -2,6 +2,11 @@ import numpy as np
 import scipy
 
 from ._lags_matrix import lags_matrix
+
+
+
+from .. import utilits 
+
 #  ktype: {exp, rbf, polynomial, sigmoid, linear, euclid, minkowsky, thin_plate, bump, polymorph}.
     
 #     kpar: kernal parameter depends on the kernal type.
@@ -142,8 +147,7 @@ def _kernel(a,b=None,ktype='rbf',kpar=1/2, take_mean = False):
             euclid, minkowsky, thin_plate, bump, polymorph}.
     * kpar: float,
         kernal parameter depends on the kernal type.
-    
-c
+
     '''
     a,b = _check_dim(a,b)
 
